@@ -1,4 +1,3 @@
-import os
 import matplotlib.pyplot as plt
 from TB2J.spinham.spin_api import SpinModel
 from TB2J.io_exchange.io_exchange import SpinIO
@@ -9,9 +8,10 @@ import numpy as np
 from TB2J import __version__
 
 
-def write_emin(**kwargs):
-    m = SpinIO.load_pickle("./")
-    m.write_Jq(kmesh=[9, 9, 9], path='./', **kwargs)
+def write_eigen(qmesh, gamma=True, path='./', output_fname='EigenJq.txt', **kwargs):
+    m = SpinIO.load_pickle(path)
+    m.write_Jq(kmesh=qmesh, path=path, gamma=gamma,
+               output_fname=output_fname, **kwargs)
 
 
 def plot_magnon_band(fname='exchange.xml',
